@@ -43,7 +43,7 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token };
 
-our $VERSION = '0.046';
+our $VERSION = '0.047';
 
 # Return true if the token can be quantified, and false otherwise
 sub can_be_quantified { return };
@@ -149,7 +149,7 @@ sub __match_setup {
 my %matcher;
 
 sub __PPIX_TOKENIZER__regexp {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( $class, $tokenizer ) = @_;	# $character unused
 
     my $mtch = $matcher{$class} ||= $class->__make_group_type_matcher();
 
